==> plantuml-1.2025.3.tar.gz: plantuml-1.2025.3/src/main/java/net/sourceforge/plantuml/command/CommandSkinParamJaws.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.command;

import net.sourceforge.plantuml.TitledDiagram;
import net.sourceforge.plantuml.jaws.Jaws;
import net.sourceforge.plantuml.regex.IRegex;
import net.sourceforge.plantuml.regex.RegexConcat;
import net.sourceforge.plantuml.regex.RegexLeaf;
import net.sourceforge.plantuml.regex.RegexRepeatedOneOrMore;
import net.sourceforge.plantuml.regex.RegexResult;
import net.sourceforge.plantuml.utils.BlocLines;
import net.sourceforge.plantuml.utils.LineLocation;

public class CommandSkinParamJaws extends SingleLineCommand2<TitledDiagram> {

	public static final CommandSkinParamJaws ME = new CommandSkinParamJaws();
	private final CommandSkinParamMultilines delegate = CommandSkinParamMultilines.ME;

	private CommandSkinParamJaws() {
		super(getRegexConcat());
	}

	static IRegex getRegexConcat() {
		return RegexConcat.build(CommandSkinParamJaws.class.getName(), RegexLeaf.start(), //
				new RegexRepeatedOneOrMore("FULL", //
						new RegexConcat( //
								new RegexLeaf("TYPE", "(skinparam|skinparamlocked)"), //
								RegexLeaf.spaceOneOrMore(), //
								new RegexLeaf(".*" + Jaws.BLOCK_E1_NEWLINE + ".*"))), //
				RegexLeaf.end()); //
	}

	@Override
	protected CommandExecutionResult executeArg(TitledDiagram diagram, LineLocation location, RegexResult arg,
			ParserPass currentPass) {
		final String full = arg.get("FULL", 0);
		BlocLines lines = BlocLines.create();
		for (String line : full.split("" + Jaws.BLOCK_E1_NEWLINE)) {
			lines = lines.addString(line);
			if (line.trim().equals("}")) {
				final CommandExecutionResult res = delegate.execute(diagram, lines, currentPass);
				if (res.isOk() == false)
					return res;
				lines = BlocLines.create();
			}
		}
		return CommandExecutionResult.ok();

	}

}

==> plantuml-1.2025.8.tar.gz: plantuml-1.2025.8/src/main/java/net/sourceforge/plantuml/command/CommandSkinParamJaws.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.command;

import net.sourceforge.plantuml.TitledDiagram;
import net.sourceforge.plantuml.jaws.Jaws;
import net.sourceforge.plantuml.regex.IRegex;
import net.sourceforge.plantuml.regex.RegexConcat;
import net.sourceforge.plantuml.regex.RegexLeaf;
import net.sourceforge.plantuml.regex.RegexRepeatedOneOrMore;
import net.sourceforge.plantuml.regex.RegexResult;
import net.sourceforge.plantuml.utils.BlocLines;
import net.sourceforge.plantuml.utils.LineLocation;

public class CommandSkinParamJaws extends SingleLineCommand2<TitledDiagram> {

	public static final CommandSkinParamJaws ME = new CommandSkinParamJaws();
	private final CommandSkinParamMultilines delegate = CommandSkinParamMultilines.ME;

	private CommandSkinParamJaws() {
		super(getRegexConcat());
	}

	static IRegex getRegexConcat() {
		return RegexConcat.build(CommandSkinParamJaws.class.getName(), RegexLeaf.start(), //
				new RegexRepeatedOneOrMore("FULL", //
						new RegexConcat( //
								new RegexLeaf(1, "TYPE", "(skinparam|skinparamlocked)"), //
								RegexLeaf.spaceOneOrMore(), //
								new RegexLeaf(".*" + Jaws.BLOCK_E1_NEWLINE + ".*"))), //
				RegexLeaf.end()); //
	}

	@Override
	protected CommandExecutionResult executeArg(TitledDiagram diagram, LineLocation location, RegexResult arg,
			ParserPass currentPass) {
		final String full = arg.get("FULL", 0);
		BlocLines lines = BlocLines.create();
		for (String line : full.split("" + Jaws.BLOCK_E1_NEWLINE)) {
			lines = lines.addString(line);
			if (line.trim().equals("}")) {
				final CommandExecutionResult res = delegate.execute(diagram, lines, currentPass);
				if (res.isOk() == false)
					return res;
				lines = BlocLines.create();
			}
		}
		diagram.setSkinParamUsed(true);
		return CommandExecutionResult.ok();

	}

}
